@@ -65,7 +65,7 @@ class DBConnect():
                 'page_size': str,  'current': str,  'columns': str,  'sort_order': str,
                 'filtered_value': str, 'start_date': str, 'end_date': str,
             },
-            optional={'start_date': '', 'end_date': ''})
+            optional={'start_date': None, 'end_date': None})
         param = parameter.param_url
         try:
             page_size = int(param['page_size'])  # 每页条数
@@ -109,7 +109,7 @@ class DBConnect():
         find_data = self.mongo_collection.find(find_dict)
         records_filtered = find_data.count()
         if not records_filtered:
-            return '请求数据不存在', 204, []
+            return '请求数据不存在', 204, [('Content-Type', 'text/plain; charset=utf-8')]
         if sort_list:
             find_data.sort(sort_list).limit(
                 page_size).skip(page_size*current)
@@ -124,4 +124,4 @@ class DBConnect():
             'records_total': self.mongo_collection.estimated_document_count(),
             'records_filtered': records_filtered,
             'query_result': query_result,
-        }, 200, []
+        }, 200, [('Content-Type', 'application/json; charset=utf-8')]
