@@ -47,10 +47,11 @@ class Parameter():
         for _k, _v in checking.items():
             try:
                 str_data = None
-                if not null_value and len(_v) == 0 and verify[_k] == str:
-                    str_data = f'参数 {_k} 不能是空字符串'
                 if type(_v) != verify[_k]:
                     str_data = f'参数 {_k} 应该是 {verify[_k]} 类型'
+                if not null_value and verify[_k] == str and not optional.__contains__(_k):
+                    if not _v.strip():
+                        str_data = f'参数 {_k} 不能是空字符串'
                 if str_data:
                     logging.warning('请求参数类型校验失败: {0}'.format(str_data))
                     abort(Response(str_data, 400, {}))
